#
# spec file for package runc
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# nodebuginfo


# MANUAL: Make sure you update this each time you update runc.
%define git_version 12644e614e25b05da6fd08a38ffa0cfe1903fdec

# Package-wide golang version
%define go_version 1.13
%define _version 1.0.0-rc93
%define project github.com/opencontainers/runc

Name:           runc
Version:        1.0.0~rc93
Release:        lp152.2.6.1
Summary:        Tool for spawning and running OCI containers
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/opencontainers/runc
Source0:        https://github.com/opencontainers/runc/releases/download/v%{_version}/runc.tar.xz#/runc-%{_version}.tar.xz
Source1:        https://github.com/opencontainers/runc/releases/download/v%{_version}/runc.tar.xz.asc#/runc-%{_version}.tar.xz.asc
Source2:        runc.keyring
Source3:        runc-rpmlintrc
# SUSE-FIX: SLE-12 has too old a glibc for memfd_create(2) and __ppc64__
#           doesn't appear to match ppc64le for some reason. This is a backport
#           of <https://github.com/opencontainers/runc/pull/2919>.
Patch1:         0001-cloned_binary-switch-from-error-to-warning-for-SYS_m.patch
# CVE-2021-30465 bsc#1185405
Patch2:         CVE-2021-30465.patch
# https://github.com/containerd/console/pull/51
Patch3:         Fix-ptsname-for-big-endian-architectures-again.patch
BuildRequires:  fdupes
BuildRequires:  go-go-md2man
# Due to a limitation in openSUSE's Go packaging we cannot have a BuildRequires
# for 'golang(API) >= 1.x' here, so just require 1.x exactly. bsc#1172608
BuildRequires:  go%{go_version}
BuildRequires:  libseccomp-devel
BuildRequires:  libselinux-devel
Recommends:     criu
# There used to be a docker-runc package which was specifically for Docker.
# Since Docker now tracks upstream more consistently, we use the same package
# but we need to obsolete the old one. bsc#1181677
# NOTE: We can't use the package version here because docker-runc used a
#       different versioning scheme by accident (1.0.0rc92 vs 1.0.0~rc92 -- and
#       GNU sort considers the former to be newer than the latter, in fact
#       1.0.0rc92 is newer than 1.0.0 according to GNU sort). So we invent a
#       fake 1.0.0.1 version.
Obsoletes:      docker-runc < 1.0.0.1
Provides:       docker-runc = 1.0.0.1.%{version}
# KUBIC-SPECIFIC: There used to be a kubic-specific docker-runc package, but
#                 now it's been merged into the one package. bsc#1181677
Obsoletes:      docker-runc-kubic < 1.0.0.1
Provides:       docker-runc-kubic = 1.0.0.1.%{version}
Obsoletes:      docker-runc = 0.1.1+gitr2819_50a19c6
Obsoletes:      docker-runc_50a19c6

%description
runc is a CLI tool for spawning and running containers according to the OCI
specification. It is designed to be as minimal as possible, and is the workhorse
of Docker. It was originally designed to be a replacement for LXC within Docker,
and has grown to become a separate project entirely.

%prep
%setup -q -n %{name}-%{_version}
# fix build on SLE-12 ppc64le
%patch1 -p1
# CVE-2021-30465 bsc#1185405
%patch2 -p1
%patch3 -p1

%build
# build runc
make BUILDTAGS="seccomp" COMMIT_NO="%{git_version}" runc
# build man pages
man/md2man-all.sh

%install
# We install to /usr/sbin/runc as per upstream and create a symlink in /usr/bin
# for rootless tools.
install -D -m0755 %{name} %{buildroot}%{_sbindir}/%{name}
install -m0755 -d %{buildroot}%{_bindir}
ln -s  %{_sbindir}/%{name} %{buildroot}%{_bindir}/%{name}

# Man pages.
install -d -m0755 %{buildroot}%{_mandir}/man8
install -m0644 man/man8/runc*.8 %{buildroot}%{_mandir}/man8

%fdupes %{buildroot}

%files
%defattr(-,root,root)
%doc README.md
%license LICENSE
%{_sbindir}/%{name}
%{_bindir}/%{name}
%{_mandir}/man8/runc*.8.gz

%changelog
* Tue Aug 31 2021 Jan Zerebecki <jzerebecki@suse.com>
- Add Fix-ptsname-for-big-endian-architectures-again.patch (bsc#1189743)
* Thu Apr 29 2021 Aleksa Sarai <asarai@suse.com>
- Add fix for CVE-2021-30465. bsc#1185405
  + CVE-2021-30465.patch
* Mon Apr 26 2021 Aleksa Sarai <asarai@suse.com>
- Backport patch to fix build on SLE-12 ppc64le.
  + 0001-cloned_binary-switch-from-error-to-warning-for-SYS_m.patch
* Wed Feb  3 2021 Aleksa Sarai <asarai@suse.com>
- Update to runc v1.0.0~rc93. Upstream changelog is available from
  https://github.com/opencontainers/runc/releases/tag/v1.0.0-rc93
  bsc#1182451 bsc#1184962
  * Cgroupv2 support is no longer considered experimental.
  * Mountinfo parsing code has been reworked significantly.
  * Special ENOSYS handling for seccomp profiles to avoid making new
  syscalls unusable for glibc.
  * Various rootless containers improvements.
  * The "selinux" and "apparmor" buildtags have been removed, and now all runc
    builds will have SELinux and AppArmor support enabled.
* Tue Feb  2 2021 Aleksa Sarai <asarai@suse.com>
- Update to handle the docker-runc removal. bsc#1181677
- Modernise go building for runc now that it has go.mod.
* Fri Aug 28 2020 Ralf Haferkamp <rhafer@suse.com>
- Upgrade to runc v1.0.0~rc92 (bsc#1175821). Upstream changelog is available
  from https://github.com/opencontainers/runc/releases/tag/v1.0.0-rc92
  * Updates to CRIU support.
  * Improvements to cgroupfs performance and correctness.
* Thu Jul  2 2020 Aleksa Sarai <asarai@suse.com>
- Upgrade to runc v1.0.0~rc91. Upstream changelog is available from
  https://github.com/opencontainers/runc/releases/tag/v1.0.0-rc91
  * This release of runc has experimental support for cgroupv2-only systems.
- Remove upstreamed patches:
  - bsc1149954-0001-sd-notify-do-not-hang-when-NOTIFY_SOCKET-is-used-wit.patch
  - bsc1168481-0001-cgroup-devices-major-cleanups-and-minimal-transition.patch
* Thu Jun 25 2020 Aleksa Sarai <asarai@suse.com>
- Switch to Go 1.13 for build.
* Wed May 13 2020 Aleksa Sarai <asarai@suse.com>
- Backport https://github.com/opencontainers/runc/pull/2391 to help fix
  bsc#1168481.
  + bsc1168481-0001-cgroup-devices-major-cleanups-and-minimal-transition.patch
* Tue Apr 14 2020 Ralf Haferkamp <rhafer@suse.com>
- Renamed patch:
  0001-sd-notify-do-not-hang-when-NOTIFY_SOCKET-is-used-wit.patch
  to
  bsc1149954-0001-sd-notify-do-not-hang-when-NOTIFY_SOCKET-is-used-wit.patch
* Wed Mar 18 2020 Ralf Haferkamp <rhafer@suse.com>
- Added fix for bsc#1149954
  * 0001-sd-notify-do-not-hang-when-NOTIFY_SOCKET-is-used-wit.patch
    (cherry pick of https://github.com/opencontainers/runc/pull/1807)
* Thu Jan 23 2020 Aleksa Sarai <asarai@suse.com>
- Upgrade to runc v1.0.0~rc10. Upstream changelog is available from
  https://github.com/opencontainers/runc/releases/tag/v1.0.0-rc10
- Drop upstreamed patches:
  - CVE-2019-19921.patch
* Tue Jan 21 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Change packagewide go version to be greater or equal to 1.10.
* Fri Jan 17 2020 Aleksa Sarai <asarai@suse.com>
- Update CVE-2019-19921 patch to match upstream PR.
  * CVE-2019-19921.patch
* Tue Jan 14 2020 Aleksa Sarai <asarai@suse.com>
- Add backported fix for CVE-2019-19921. bsc#1160452
  + CVE-2019-19921.patch
* Sat Oct  5 2019 Aleksa Sarai <asarai@suse.com>
- Upgrade to runc v1.0.0~rc9. Upstream changelog is available from
  https://github.com/opencontainers/runc/releases/tag/v1.0.0-rc9
- Remove upstreamed patches:
  - CVE-2019-16884.patch
* Thu Sep 26 2019 Aleksa Sarai <asarai@suse.com>
- Add backported fix for CVE-2019-16884. bsc#1152308
  + CVE-2019-16884.patch
- Add runc-rpmlintrc to drop runc-test rpmlint warnings.
* Mon Apr 29 2019 Aleksa Sarai <asarai@suse.com>
- Upgrade to runc v1.0.0~rc8. Upstream changelog is available from
  https://github.com/opencontainers/runc/releases/tag/v1.0.0-rc8
- Includes upstreamed patches for regressions (bsc#1131314 bsc#1131553).
- Remove upstreamed patches:
  - CVE-2019-5736.patch
* Wed Feb  6 2019 Aleksa Sarai <asarai@suse.com>
- Add fix for CVE-2019-5736 (effectively copying /proc/self/exe during re-exec
  to avoid write attacks to the host runc binary). bsc#1121967
  + CVE-2019-5736.patch
* Wed Dec 19 2018 clee@suse.com
- Update go requirements to >= go1.10 to fix
  * bsc#1118897 CVE-2018-16873
    go#29230 cmd/go: remote command execution during "go get -u"
  * bsc#1118898 CVE-2018-16874
    go#29231 cmd/go: directory traversal in "go get" via curly braces in import paths
  * bsc#1118899 CVE-2018-16875
    go#29233 crypto/x509: CPU denial of service
* Thu Dec 13 2018 dorf@suse.com
- Require golang = 1.10.
* Thu Nov 29 2018 Aleksa Sarai <asarai@suse.com>
- Upgrade to runc v1.0.0~rc6. Upstream changelog is available from
  https://github.com/opencontainers/runc/releases/tag/v1.0.0-rc6
* Wed Oct 31 2018 Valentin Rothberg <vrothberg@suse.com>
- Create a symlink in /usr/bin/runc to enable rootless Podman and Buildah.
* Wed Jun 13 2018 dcassany@suse.com
- Make use of %%license macro
* Tue Jun  5 2018 asarai@suse.com
- Remove 'go test' from %%check section, as it has only ever caused us problems
  and hasn't (as far as I remember) ever caught a release-blocking issue. Smoke
  testing has been far more useful. boo#1095817
* Tue Feb 27 2018 asarai@suse.com
- Upgrade to runc v1.0.0~rc5. Upstream changelog is available from
  https://github.com/opencontainers/runc/releases/tag/v1.0.0-rc5
- Remove patch now merged upstream.
  - bsc1053532-0001-makefile-drop-usage-of-install.patch
* Thu Aug 17 2017 asarai@suse.com
- Use .tar.xz provided by upstream, as well as include the keyring to allow
  full provenance of the source.
* Sun Aug 13 2017 asarai@suse.com
- Use the upstream Makefile, to ensure that we always include the version
  information in runc. This was confusing users (and Docker). bsc#1053532
- Add a backported patch to fix a Makefile bug.
  https://github.com/opencontainers/runc/pull/1555
  + bsc1053532-0001-makefile-drop-usage-of-install.patch
* Thu Aug 10 2017 asarai@suse.com
- Update to runc v1.0.0-rc4. Upstream changelog:
  + runc now supports v1.0.0 of the OCI runtime specification. #1527
  + Rootless containers support has been released. The current state of
  this feature is that it only supports single-{uid,gid} mappings as an
  unprivileged user, and cgroups are completely unsupported. Work is
  being done to improve this. #774
  + Rather than relying on CRIU version nnumbers, actually check if the
  system supports pre-dumping. #1371
  + Allow the PIDs cgroup limit to be updated. #1423
  + Add support for checkpoint/restore of containers with orphaned PTYs
  (which is effectively all containers with terminal=true). #1355
  + Permit prestart hooks to modify the cgroup configuration of a
  container. #1239
  + Add support for a wide variety of mount options. #1460
  + Expose memory.use_hierarchy in MemoryStats. #1378
  * Fix incorrect handling of systems without the freezer cgroup. #1387
  * Many, many changes to switch away from Go's "syscall" stdlib to
  "golang.org/x/sys/unix". #1394 #1398 #1442 #1464 #1467 #1470 #1474
  [#1478] #1491 #1482 #1504 #1519 #1530
  * Set cgroup resources when restoring a container. #1399
  * Switch back to using /sbin as the installation directory. #1406
  * Remove the arbitrary container ID length restriction. #1435
  * Make container force deletion ignore non-existent containers. #1451
  * Improve handling of arbitrary cgroup mount locations when populating
  cpuset. #1372
  * Make the SaneTerminal interface public. #1479
  * Fix cases where runc would report a container to be in a "Running"
  state if the init was a zombie or dead. #1489
  * Do not set supplementary groups for numeric users. #1450
  * Fix various issues with the "owner" field in runc-list. #1516
  * Many other miscellaneous fixes, some of which were made by first-time
  contributors. Thanks, and welcome to the project! #1406 #1400 #1365
  [#1396] #1402 #1414 #1412 #1408 #1418 #1425 #1428 #1436 #1433 #1438
  [#1410] #1447 #1388 #1484 #1481 #1496 #1245 #1524 #1534 #1526 #1533
  - Remove any semblance of non-Linux support. #1502
  - We no longer use shfmt for testing. #1510
* Wed Aug  2 2017 asarai@suse.com
- Use -buildmode=pie for tests and binary build. bsc#1048046 bsc#1051429
- Cleanup seccomp builds similar to bsc#1028638
- Remove the usage of 'cp -r' to reduce noise in the build logs.
* Thu Jul  6 2017 thipp@suse.de
- switch to opencontainers/runc master branch
- remove CVE-2016-9962.patch
- stop providing docker-runc
* Thu May  4 2017 jmassaguerpla@suse.com
- fix the golang requirement to 1.7 to the subpackages
* Tue May  2 2017 jmassaguerpla@suse.com
- fix golang requirement to 1.7
* Fri Apr 28 2017 jengelh@inai.de
- Substitute %%__-type macro indirections
* Thu Apr 13 2017 jmassaguerpla@suse.com
- update version to the one required by docker-17.04.0-ce (bsc#1034053)
  remove ignore_cgroup2_mountpoint.patch . This is already included in
  the upstream source code.
* Wed Apr 12 2017 jmassaguerpla@suse.com
- Make sure this is being built with go 1.7
* Tue Apr 11 2017 jmassaguerpla@suse.com
- remove the go_arches macro because we are using go1.7 which
  is available in all archs
* Wed Mar 29 2017 jmassaguerpla@suse.com
- fix bsc#1028113 - runc: make sure to ignore cgroup v2 mountpoints
  This is a backport of https://github.com/opencontainers/runc/pull/1266
  + ignore_cgroup2_mountpoint.patch
* Fri Feb 24 2017 jmassaguerpla@suse.com
- update to docker-1.13.0 requirement
* Fri Jan 13 2017 jmassaguerpla@suse.com
- fix CVE-2016-9962 bsc#1012568 and applying the patch
  CVE-2016-9962.patch, because 1.12.6 partially fixes it (it contains
  the first patch attached in bsc#1012568)
* Mon Dec 19 2016 jmassaguerpla@suse.com
- update runc to the version used in docker 1.12.5 (bsc#1016307).
  This fixes bsc#1015661
* Mon Dec 19 2016 asarai@suse.com
- For the moment, we have to switch to using Docker's fork of runC. This *will*
  be solved properly by creating a new package purely for Docker's runC fork,
  because it's quite silly to tie OCI project releases to Docker's vendoring
  scheme. Once this is fixed, this package will be switch to being purely-OCI.
* Fri Dec 16 2016 jmassaguerpla@suse.com
- add the /usr/bin/docker-run symlink to partially fix bsc#1015661
* Thu Nov 24 2016 jmassaguerpla@suse.com
- fix version by adding a revision "counter" so that it will always
  increase
  fix bsc#1009961
* Thu Oct 13 2016 jmassaguerpla@suse.com
- update to 02f8fa7 because that is the needed version for docker 1.12.1 (bsc#1004490)
* Wed Sep 21 2016 jengelh@inai.de
- Run fdupes.
* Mon Sep 19 2016 jmassaguerpla@suse.com
- fix go_arches definition: use global instead of define, otherwise
  it fails to build
* Fri Aug 26 2016 asarai@suse.com
- Remove docker-runc symlink because it's been fixed within the Docker
  package. bsc#978260
* Thu Aug 25 2016 jmassaguerpla@suse.com
- Create a symlink /usr/sbin/docker-runc -> /usr/sbin/docker
  Docker expects this symlink to exist bsc#978260
* Thu Aug 25 2016 jmassaguerpla@suse.com
- Remove GOPATH at the end of the GOPATH assignment
  cause GOPATH is empty and if we do that, we get the path ""
  appended, which causes gcc6-go to complain
* Wed Aug 24 2016 jmassaguerpla@suse.com
- add go_arches in project configuration: this way, we can use the
  same spec file but decide in the project configuration if to
  use gc-go or gcc-go for some archs.
* Thu Aug 18 2016 jmassaguerpla@suse.com
- use gcc6-go instead of gcc5-go (bsc#988408)
- build ppc64le with gc-go because this version builds with gc-go 1.6
* Thu Aug 18 2016 cbrauner@suse.de
- bump git commit id to the one required by docker v1.12.0 (bsc#995058)
- run unit tests during package build
- remove seccomp-use-pkg-config.patch
  The patch is now upstream.
- remove GO_BUILD_FLAGS macro and substitute with BUILDFLAGS env variable to
  allow for easier string appending.
- only run unit test on architectures that provide the go list and go test tools
* Wed Aug 17 2016 cbrauner@suse.de
- Add runc-test package which contains the source code and the test. This
  package will be used to run the integration tests.
- Simplify package build and check sections: Instead of symlinking we default to
  cp -avr. go list gets confused by symlinks hence, we need to copy the source
  code anyway if we want to run unit tests during package build at some point.
* Fri Apr 29 2016 asarai@suse.de
  * Update to runC 0.1.1. (bsc#989566 FATE#320763) Changelog from upstream:
  This release includes a bug fix for adding the selinux mount label in the specification.
* Tue Apr 19 2016 asarai@suse.de
  * Don't use gcc-go for aarch64, since gc has grown support for it and is more
  stable.
* Fri Apr 15 2016 asarai@suse.de
  * Disable seccomp entirely for aarch64 builds, since it is not provided on all
  SUSE platforms.
* Wed Apr 13 2016 asarai@suse.de
  * Update to runC 0.1.0. Changelog from upstream:
  This release updates runc to the OCI runtime specification v0.5.0 and includes
  various fixes and features.
  Features:
  + cgroups: pid limits and stats
  + cgroups: kmem stats
  + systemd cgroup support
  + libcontainer specconv package
  + no pivot root option
  + numeric ids are treated as uid/gid
  + hook improvements
  Bug Fixes:
  * log flushing
  * atomic pid file creation
  * init error recovery
  * seccomp logging removed
  * delete container on aborted start
  * /dev bind mount handling
* Wed Mar 30 2016 asarai@suse.de
  * Install to /usr/sbin.  https://github.com/opencontainers/runc/pull/702
* Sun Mar 27 2016 asarai@suse.de
  * Added runC man pages.
  * Recommended criu, since it's required for the checkpoint and restore
  functionality.
* Sun Mar 27 2016 asarai@suse.de
  * Small updates to method of compilation to better match Makefile.
* Mon Mar 21 2016 asarai@suse.de
  * Make compilation work on gcc-go only systems (ppc and s390).
* Mon Mar 21 2016 asarai@suse.de
  * initial import of runC 0.0.9
  * add patch seccomp-use-pkg-config.patch which allows us to build runC, since
  they assume that the seccomp.h file lives at /usr/include/seccomp.h.
